Hybrid Ranking Filling Network for Text-to-JSON

Environment:

    python: 3.6 or higher
    pyTorch: 1.7.0 or higher
    numpy: 1.14.3 or higher
    transformers: 2.5.1 or higher
    chinese2digits: 4.0.2 or higher
    cuda: 9.2 or higher
